- Removed user_config patch.

- Fix nonrootconf patch (#400921).
This commit is contained in:
Martin Nagy 2007-11-30 13:34:01 +00:00
parent dc65694a9c
commit 608f0a38f2
3 changed files with 15 additions and 22 deletions

View File

@ -1,23 +1,27 @@
--- vsftpd-2.0.1/parseconf.c.nonrootconf 2004-07-02 13:23:56.000000000 +0200
+++ vsftpd-2.0.1/parseconf.c 2005-02-08 09:37:26.642905392 +0100
@@ -15,6 +15,7 @@

View File

@ -1,11 +0,0 @@
--- vsftpd-2.0.3/twoprocess.c.test 2005-08-31 11:49:58.000000000 +0200
+++ vsftpd-2.0.3/twoprocess.c 2005-08-31 11:58:11.000000000 +0200
@@ -422,7 +424,7 @@ handle_per_user_config(const struct myst
{
vsf_parseconf_load_file(str_getbuf(&filename_str), 1);
}
- else
+ else if (vsf_sysutil_statbuf_get_uid(p_statbuf) != VSFTP_ROOT_UID)
{
die("reading non-root config file");
}

View File

@ -28,7 +28,6 @@ Patch11: vsftpd-1.2.1-nonrootconf.patch
Patch13: vsftpd-2.0.3-background.patch
Patch14: vsftpd-2.0.3-daemonize_fds.patch
Patch15: vsftpd-2.0.1-kickline.patch
Patch16: vsftpd-2.0.3-user_config.patch
Patch17: vsftpd-2.0.3-pam_hostname.patch
Patch18: vsftpd-close-std-fds.patch
Patch19: vsftpd-2.0.5-default_ipv6.patch
@ -88,7 +87,6 @@ cp %{SOURCE1} .
%patch13 -p1 -b .background
%patch14 -p1 -b .fds
%patch15 -p1 -b .kickline
%patch16 -p1 -b .user_config
%patch17 -p1 -b .old-pam
%patch18 -p1 -b .close-fds
%patch19 -p1 -b .ipv6
@ -171,6 +169,8 @@ fi
- Fix bad handling of unique files (#392231).
- Added userlist_log option.
- Allow usernames to begin with underscore or dot (#339911).
- Removed user_config patch.
- Fix nonrootconf patch (#400921).
* Thu Nov 08 2007 Martin Nagy <mnagy@redhat.com> - 2.0.5-20
- Correct calling of pam_end (#235843).
--- vsftpd-2.0.1/twoprocess.c.nonrootconf 2004-07-02 18:47:51.000000000 +0200
+++ vsftpd-2.0.1/twoprocess.c 2005-02-08 09:37:26.641905544 +0100
@@ -416,12 +416,16 @@
@@ -416,11 +416,17 @@
str_append_char(&filename_str, '/');
str_append_str(&filename_str, p_user_str);
retval = str_stat(&filename_str, &p_statbuf);
- /* Security - ignore unless owned by root */
- if (!vsf_sysutil_retval_is_error(retval) &&
- vsf_sysutil_statbuf_get_uid(p_statbuf) == VSFTP_ROOT_UID)
+ /* Security - die unless owned by root */
if (!vsf_sysutil_retval_is_error(retval) &&
vsf_sysutil_statbuf_get_uid(p_statbuf) == VSFTP_ROOT_UID)
+ if (!vsf_sysutil_retval_is_error(retval))
{
vsf_parseconf_load_file(str_getbuf(&filename_str), 1);
- vsf_parseconf_load_file(str_getbuf(&filename_str), 1);
+ if (vsf_sysutil_statbuf_get_uid(p_statbuf) == VSFTP_ROOT_UID)
+ {
+ vsf_parseconf_load_file(str_getbuf(&filename_str), 1);
+ }
+ else
+ {
+ die("reading non-root config file");
+ }
}
+ else
+ {
+ die("reading non-root config file");
+ }
str_free(&filename_str);
vsf_sysutil_free(p_statbuf);
}